==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/lv/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'Pielāgotie lauki',
    'field'		                => 'Lauks',
    'about_fieldsets_title'		=> 'Par lauka laukiem',
    'about_fieldsets_text'		=> 'Lauka ailes ļauj jums izveidot pielāgotu lauku grupas, kuras bieži tiek atkārtoti izmantotas konkrētu aktīvu veidu tipiem.',
    'custom_format'             => 'Pielāgots formāts ...',
    'encrypt_field'      	        => 'Šifrējiet šī lauka vērtību datu bāzē',
    'encrypt_field_help'      => 'BRĪDINĀJUMS: lauka šifrēšana padara to neizpētītu.',
    'encrypted'      	        => 'Šifrēts',
    'fieldset'      	        => 'Lauka laukums',
    'qty_fields'      	      => 'Daudzi lauki',
    'fieldsets'      	        => 'Lauka lauki',
    'fieldset_name'           => 'Lauka nosaukums',
    'field_name'              => 'Lauka nosaukums',
    'field_values'            => 'Lauka vērtības',
    'field_values_help'       => 'Pievienot izvēles iespējas, pa vienai katrā rindiņā. Tukšās rindas, izņemot pirmo rindu, tiks ignorētas.',
    'field_element'           => 'Veidlapas elements',
    'field_element_short'     => 'Elements',
    'field_format'            => 'Formāts',
    'field_custom_format'     => 'Pielāgotais formāts',
    'field_custom_format_help'     => 'Šajā laukā var izmantot regulāro izteiksmi, lai pārbaudītu. Tai ir jāsākas ar "regex:". Piemēram, lai pārbaudītu, ka pielāgotais lauks satur derīgu IMEI (15 cipari), būtu jāizmanto vērtība <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obligāts',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Izmantoti modeļi',
    'order'   		            => 'Pasūtījums',
    'create_fieldset'         => 'Jauns lauka laukums',
    'create_field'            => 'Jauna pielāgota lauks',
    'value_encrypted'      	        => 'Šī lauka vērtība ir šifrēta datu bāzē. Tikai admin lietotāji varēs apskatīt atšifrēto vērtību',
    'show_in_email'     => 'Vai iekļaut šī lauka vērtību lietotājiem nosūtītajos e-pasta paziņojumos? Šifrētie lauki nevar būt iekļauti e-pasta ziņojumos.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/lv/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Pielāgotie lauki',
    'manage'                    => 'Manage',
    'field'		                => 'Lauks',
    'about_fieldsets_title'		=> 'Par lauka laukiem',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Šifrējiet šī lauka vērtību datu bāzē',
    'encrypt_field_help'      => 'BRĪDINĀJUMS: lauka šifrēšana padara to neizpētītu.',
    'encrypted'      	        => 'Šifrēts',
    'fieldset'      	        => 'Lauka laukums',
    'qty_fields'      	      => 'Daudzi lauki',
    'fieldsets'      	        => 'Lauka lauki',
    'fieldset_name'           => 'Lauka nosaukums',
    'field_name'              => 'Lauka nosaukums',
    'field_values'            => 'Lauka vērtības',
    'field_values_help'       => 'Pievienot izvēles iespējas, pa vienai katrā rindiņā. Tukšās rindas, izņemot pirmo rindu, tiks ignorētas.',
    'field_element'           => 'Veidlapas elements',
    'field_element_short'     => 'Elements',
    'field_format'            => 'Formāts',
    'field_custom_format'     => 'Pielāgotais formāts',
    'field_custom_format_help'     => 'Šajā laukā var izmantot regulāro izteiksmi, lai pārbaudītu. Tai ir jāsākas ar "regex:". Piemēram, lai pārbaudītu, ka pielāgotais lauks satur derīgu IMEI (15 cipari), būtu jāizmanto vērtība <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obligāts',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Izmantoti modeļi',
    'order'   		            => 'Pasūtījums',
    'create_fieldset'         => 'Jauns lauka laukums',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Jauna pielāgota lauks',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'Šī lauka vērtība ir šifrēta datu bāzē. Tikai admin lietotāji varēs apskatīt atšifrēto vērtību',
    'show_in_email'     => 'Vai iekļaut šī lauka vērtību lietotājiem nosūtītajos e-pasta paziņojumos? Šifrētie lauki nevar būt iekļauti e-pasta ziņojumos.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code> :db_column </code> but should be :expected </code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
];
